%global url_ver %(echo %{version} | cut -d. -f1,2)

Summary:	ODBC driver library for connecting to MariaDB and MySQL servers
Name:		mariadb-connector-odbc
Version:	3.1.15
Release:	%mkrel 2
Group:		Development/Databases
License:	LGPLv2+
URL:		https://mariadb.com/kb/en/library/mariadb-connector-odbc/
Source0:	https://downloads.mariadb.org/interstitial/connector-odbc-%{version}/mariadb-connector-odbc-%{version}-src.tar.gz
Patch0:		libraries_include_path.patch
Patch1:		mariadb-connector-odbc-cmake-4.0.patch
BuildRequires:	cmake
BuildRequires:	mariadb-devel
BuildRequires:	unixODBC-devel
BuildRequires:	pkgconfig(openssl)
Requires(preun):	unixODBC
Requires(post):		unixODBC
Requires:	unixODBC
Provides:	mysql-connector-odbc
Obsoletes:	mysql-connector-odbc < 5.3.2-5

%description
MariaDB Connector/ODBC is a standardized database driver using the industry
standard Open Database Connectivity (ODBC) API.

It supports ODBC Standard 3.5, can be used as a drop-in replacement for
MySQL Connector/ODBC, and it supports both Unicode and ANSI modes.

%prep
%setup -q -n %{name}-%{version}-src
%autopatch -p1

%build
export CFLAGS="%{optflags} -pthread -I%{_includedir}/mysql"
%cmake \
	-DMARIADB_LINK_DYNAMIC:BOOL=TRUE \
	-DWITH_OPENSSL:BOOL=TRUE \
	-DINSTALL_DOCDIR="%{_docdir}/%{name}" \
	-DINSTALL_LICENSEDIR="%{_licensedir}/%{name}"

%cmake_build

%install
%cmake_install

# not needed?
rm -rf %{buildroot}%{_libdir}/pkgconfig/libmaodbc.pc

mkdir -p %{buildroot}%{_datadir}/%{name}/
cat >> %{buildroot}%{_datadir}/%{name}/%{name}.ini << EOF
[MariaDB ODBC 3.1 Driver]
Driver = %{_libdir}/mariadb/libmaodbc.so
Description = MariaDB Connector/ODBC v3.1
EOF

rm -rf %{buildroot}%{_docdir}

%preun
if [[ $1 -eq 0 ]] ; then
  if [[ -x %{_bindir}/odbcinst ]]; then
    %{_bindir}/odbcinst -v -d -u -n 'MariaDB ODBC 3.1 Driver'
  fi
fi

%post
if [[ $1 -eq 1 ]] ; then
  if [[ -x %{_bindir}/odbcinst ]]; then
    %{_bindir}/odbcinst -v -d -i -f %{_datadir}/%{name}/%{name}.ini
  fi
fi

%triggerun -- mariadb-connector-odbc < 3.1.13
if [[ -x %{_bindir}/odbcinst ]]; then
  %{_bindir}/odbcinst -v -d -u -n 'MariaDB ODBC 3.1 Driver'
  %{_bindir}/odbcinst -v -d -i -f %{_datadir}/%{name}/%{name}.ini
fi

%files
%license COPYING
%doc README
%dir %{_libdir}/mariadb/
%{_libdir}/mariadb/libmaodbc.so
%dir %{_datadir}/%{name}/
%{_datadir}/%{name}/%{name}.ini


%changelog
* Tue Jul 08 2025 aurr <aurr> 3.1.15-2.mga10
+ Revision: 2252424
- fix build with cmake-4.0
+ umeabot <umeabot>
- Mageia 10 Mass Rebuild

* Fri Apr 22 2022 wally <wally> 3.1.15-1.mga9
+ Revision: 1852652
- new version 3.1.15

* Sat Apr 02 2022 umeabot <umeabot> 3.1.13-2.mga9
+ Revision: 1841120
- Mageia 9 Mass Rebuild

* Wed Jul 07 2021 wally <wally> 3.1.13-1.mga9
+ Revision: 1735122
- new version 3.1.13
- fix driver install location

* Sun May 09 2021 wally <wally> 3.1.12-1.mga9
+ Revision: 1722350
- new version 3.1.12

* Mon Dec 21 2020 wally <wally> 3.1.11-1.mga8
+ Revision: 1662561
- new version 3.1.11

* Sat Dec 05 2020 luigiwalser <luigiwalser> 3.1.10-1.mga8
+ Revision: 1653053
- 3.1.10
- remove upstreamed patch

* Wed Aug 05 2020 luigiwalser <luigiwalser> 3.1.9-1.mga8
+ Revision: 1611224
- add patch from fedora to fix docs installation
- 3.1.9

* Sat Apr 11 2020 wally <wally> 3.1.7-1.mga8
+ Revision: 1566399
- new version 3.1.7

* Thu Feb 20 2020 umeabot <umeabot> 3.1.6-2.mga8
+ Revision: 1545952
- Mageia 8 Mass Rebuild

* Thu Jan 30 2020 wally <wally> 3.1.6-1.mga8
+ Revision: 1485631
- new version 3.1.6
- build with new cmake macros

* Sat Nov 16 2019 wally <wally> 3.1.5-2.mga8
+ Revision: 1461263
- fix driver name in .ini

* Sat Nov 16 2019 wally <wally> 3.1.5-1.mga8
+ Revision: 1461262
- new version 3.1.5

* Fri Aug 30 2019 wally <wally> 3.1.3-1.mga8
+ Revision: 1435297
- vew version 3.1.3

* Sat Aug 03 2019 wally <wally> 3.1.2-1.mga8
+ Revision: 1427142
- new version 3.1.2

* Fri Jul 05 2019 wally <wally> 3.1.1-1.mga8
+ Revision: 1418808
- new version 3.1.1

* Fri Mar 22 2019 wally <wally> 3.0.8-1.mga7
+ Revision: 1379638
- new version 3.0.8
- add header include fix patch from Fedora

* Sun Sep 23 2018 umeabot <umeabot> 3.0.2-2.mga7
+ Revision: 1299457
- Mageia 7 Mass Rebuild

* Mon Dec 25 2017 wally <wally> 3.0.2-1.mga7
+ Revision: 1184622
- add ODBC driver configuration file
- imported package mariadb-connector-odbc

